@@ -5,7 +5,7 @@ require DynaLoader;
 use vars qw/  @ISA $VERSION /;
 @ISA = 'DynaLoader';
 
-$VERSION = '2.06';
+$VERSION = '2.07';
 
 bootstrap Text::Hunspell $VERSION;
 
@@ -98,9 +98,6 @@ Text::Hunspell - Perl interface to the GNU Hunspell library
     print "Morphological modification generator...\n";
     print Data::Dumper::Dumper(\@suggestions);
 
-    # Deletes the underlying Hunspell C/C++ object
-    $speller->delete($speller);
-
 
 =head1 DESCRIPTION
 
@@ -187,12 +184,6 @@ Returns morphologically modified stem like $word.
 TODO WHY IS THIS DIFFERENT FROM generate2() ???
 EXPLAIN.
 
-=head2 C<< $speller->delete($speller) >>
-
-Deletes the speller class.
-
-TODO WHY IS THIS NEEDED?? Called on C<$speller> and needs C<$speller> ???
-
 =head1 BUGS
 
 Probably. Yes, definitely.
